pub unsafe extern "C" fn cufftCreate(
handle: *mut cufftHandle,
) -> cufftResultExpand description
Creates only an opaque handle, and allocates small data structures on the host. The cufftMakePlan*() calls actually do the plan generation.
Return value
cufftResult::CUFFT_ALLOC_FAILED: The allocation of resources for the plan failed.cufftResult::CUFFT_INTERNAL_ERROR: An internal driver error was detected.cufftResult::CUFFT_INVALID_VALUE: One or more invalid parameters were passed to the API.cufftResult::CUFFT_SETUP_FAILED: The cuFFT library failed to initialize.cufftResult::CUFFT_SUCCESS: cuFFT successfully created the FFT plan.