cufftSetAutoAllocation

Function cufftSetAutoAllocation 

pub unsafe extern "C" fn cufftSetAutoAllocation(
    plan: cufftHandle,
    autoAllocate: c_int,
) -> cufftResult
cufftSetAutoAllocation indicates that the caller intends to allocate and manage work areas for plans that have been generated. cuFFT default behavior is to allocate the work area at plan generation time. If cufftSetAutoAllocation has been called with autoAllocate set to 0 (“false”) prior to one of the cufftMakePlan*() calls, cuFFT does not allocate the work area. This is the preferred sequence for callers wishing to manage work area allocation.

Parameters

Return value