cufftHandle

Type Alias cufftHandle 

pub type cufftHandle = c_int;
A handle type used to store and access cuFFT plans. The user receives a handle after creating a cuFFT plan and uses this handle to execute the plan.