pub unsafe extern "C" fn cufftSetAutoAllocation(
plan: cufftHandle,
autoAllocate: c_int,
) -> cufftResultExpand description
cufftSetAutoAllocation indicates that the caller intends to allocate and manage work areas for plans that have been generated. cuFFT default behavior is to allocate the work area at plan generation time. If cufftSetAutoAllocation has been called with autoAllocate set to 0 (“false”) prior to one of the cufftMakePlan*() calls, cuFFT does not allocate the work area. This is the preferred sequence for callers wishing to manage work area allocation.
Parameters
plan:cufftHandlereturned bycufftCreate.autoAllocate: Indicates whether to allocate work area.
Return value
cufftResult::CUFFT_INTERNAL_ERROR: An internal driver error was detected.cufftResult::CUFFT_INVALID_PLAN: Theplanparameter is not a valid handle.cufftResult::CUFFT_SUCCESS: cuFFT successfully returned the size of the work space.